% ----------------------------------------------------------------
%   DDSFPLOT.M   DDS figure frequency plot file.
%   File plots the power spectrum of DDS output signal.
%
%   Input:      rPsdQ .. calculated power spectum (discrete
%                        lines) of the output singnal.
%               FigFloor .. spectral plotting floor in [dB],
%                           if lower then the figure actual
%                           picture floor, then the figure remains
%                           unchanged
%
%               Plotting flags (0-no or 1-yes values):
%                 gShell .. running in GUI
%                 gData  .. print the data in the plot
%                 gInPlot .. where to plot data in the
%                            plot - in the figure itself
%                            or by the figure
%                 gAugment .. augment the spectrum by one frequency
%                             sample to get nice symetric figure
%                             from 0 to Fv (included)
%                 gStem .. stem (vertical lines) the spectrum instead
%                          of plot. Keep this 0 and set for 1 only
%                          when you SEE the necessity. Memory and
%                          consuming!
%
%   Output:     Power spectrum plot in dB scale.
%   Calls:      ddsgset.m .. only if in GUI
%               ddstext.m
%               ddsstema.m
%               ddsplota.m
%               ddsstemf.m
%               ddsplotf.m
%
%   Author: Martin Pechanec, Febraury 14, 1998
%           pechanec@iname.com
% ----------------------------------------------------------------


% -- Get all the parameters from the active control
% only if run from the shell
if 1 == gShell,
  ddsgset;
end

% Open new figure
figure;

% Get the text strings
ddstext;

% -- Prepare axes
if 1 == gData & 0 == gInPlot,
  iHandleAxesText = axes( 'Position', [0 0 1 1], 'Visible', 'off' );
  axes( 'Position', [ .1  .1  .7  .8 ] );
end

% -- Plot the power spectrum accordingly
if 1 == gAugment
  if 1 == gStem
    ddsstema( Fv, rPsdQ );
  else,
    ddsplota( Fv, rPsdQ );
  end
else
  if 1 == gStem
    ddsstemf( Fv, rPsdQ );
  else,
    ddsplotf( Fv, rPsdQ );
  end
end

% -- Scale the power dB axis
rAxis = axis;
FigBottom = max( FigFloor, rAxis(3) );

% Check the bottom. If cross, check, whether the user
% wanted say -60dB but entered 60dB insted
if FigBottom >= rAxis(4)
  FigBottom = -FigBottom;
  FigBottom = max( FigBottom, rAxis(3) );
end

% Check again
if FigBottom >= rAxis(4)

% User is totally wrong, do not change the range
  FigBottom = rAxis(3);
end

% Set the new power [dB] axis range
axis( [ rAxis(1:2), FigBottom, rAxis(4) ] );

% -- Add title and labels
title( ['DDS power spectrum' sLength] );
xlabel( 'Frequency [Hz]' );
ylabel( 'Power [dB] (0dB is the power of 1*cos{\omega_v}t)' );

% -- Add the text data
if 1 == gData
  if 1 == gInPlot
    rAxis = axis;
    iHadleText = text( 0.8*rAxis(2), rAxis(4), rsText, ...
                        'HorizontalAlignment', 'left', ...
                        'VerticalAlignment', 'top' );
  else
    set( gcf, 'currentaxes', iHandleAxesText );
    text( .82, .62, rsText, 'FontSize', 10 );
  end
end
