% -----------------------------------------------------------------------
% Direct Digital Synthesis simulator Graphic User Interface.
% Main simulator file. Run the simulator by typing
%
%   ddsg
%
% at the MATLAB promtp. The ddsg.m file and its associated ddsg.mat
% file must be on your path.
%
%   Author: Martin Pechanec, Febraury 14, 1997
%           pechanec@iname.com
%
%   Versions:
%     April 23, 1998:     gResize and rDdsGuiPosition added, ddsg.m
%                         changed from a function to a plain M-file
%
%     February 14, 1998:  First release
%
% -----------------------------------------------------------------------

% -- Set format to compact
format compact;

% -- Load the ddsg.mat file
load ddsg

% -- Set the shell variable .. we are in the GUI
gShell = 1;

% -- Set the GUI controlling variables .. needed to be
% changed if the figure size clips off some of the
% GUI

% -- Center the GUI on the screen
if ( 1 ~= exist( 'gCenter' ) )
  gCenter = 1;
end

% -- Resize the GUI figure
if ( 1 ~= exist( 'gResize' ) )
  gResize = 0;    % Resize the GUI figure. 0 .. no, 1 .. yes
                  % Default should be no (0). If there are problems
                  % with the size, set this to yes (1), resize the
                  % main GUI window to the comfortable size,
                  % from the MATLAB command line type
                  % get( gcf, 'Position' )
                  % which returns vector
                  % [iLeft iBottom iWidth iHeight]
                  % set the values to the the variables
                  % bellow in this file and set the gResize
                  % back to 0.
end

% Check the resize flag
if ( 0 ~= gResize )
  sResize = 'on';
else
  sResize = 'off';
end

% -- Position the GUI window
% Make sure the root screen units are pixels
set( 0, 'Units', 'pixels' );
if 0 ~= gCenter

% -- Center the GUI on the screen .. [left bottom width height]
% The GUI window width is 340 and height is 410
  rScreenSize = get( 0, 'ScreenSize' );

% Make the screen footer width to be iFooter pixels and the
% distance of the figure top from the screen top should
% be at least iHeaderMin pixels. The same for the left
% edges iLeftMin pixels.

  iGuiWidth = 421;
  iGuiHeight = 555;
  iHeaderMin = 20;
  iFooter = 35;
  iLeftMin = 20;

  rDdsGuiPosition = [ ( rScreenSize(3)-iGuiWidth )/2, ...
                      ( rScreenSize(4)+iFooter-iGuiHeight)/2, ...
                      iGuiWidth, ...
                      iGuiHeight ];

  if rDdsGuiPosition(2)+iGuiHeight > rScreenSize(4)-iHeaderMin
    rDdsGuiPosition(2) = rScreenSize(4) - iHeaderMin - iGuiHeight;
  end

  if rDdsGuiPosition(1) < iLeftMin
    rDdsGuiPosition(1) = iLeftMin;
  end
  clear iFooter iGuiWidth iGuiHeight iLeftMin

else

% -- GUI figure position on the screen in pixels.
  if 1 ~= exist( 'iDdsWidth' )
    iWidth = 421;   % GUI figure width in pixels
  end

  if 1 ~= exist( 'iDdsHeight' )
    iHeight = 555;  % GUI figure height in pixels
  end

  if 1 ~= exist( 'iDdsLeft' )
    iLeft = 200;    % Distance of the left figure edge
                    % from the monitor (screen) left edge.
  end

  if 1 ~= exist( 'iDdsBottom' )
    iBottom = 100;  % Distance of the figure bottom edge
                    % from the monitor (screen) bottom edge.
  end

% Set the position vector
  rDdsGuiPosition = [ iDdsLeft, iDdsBottom, iDdsWidth, iDdsHeight ];
end

% ---- Create the GUI objects
a = figure('Color',[0.8 0.8 0.8], ...
        'Colormap',mat0, ...
        'Name','DDS Simulator', ...
        'PointerShapeCData',mat1, ...
        'Position',rDdsGuiPosition, ...
        'RendererMode','manual', ...
        'Resize',sResize, ...
        'Tag','Figure_eDds');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Position',[6.75 193.5 302.25 45], ...
        'Style','frame', ...
        'Tag','Frame1');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Position',[6.75 341.25 301.5 45], ...
        'Style','frame', ...
        'Tag','Frame1');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Position',[6.75 291.75 302.25 45], ...
        'Style','frame', ...
        'Tag','Frame1');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Position',[6.75 243 302.25 45], ...
        'Style','frame', ...
        'Tag','Frame1');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Position',[8.25 7.5 301.5 60], ...
        'Style','frame', ...
        'Tag','Frame3');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Position',[8.25 77.25 81.75 106.5], ...
        'Style','frame', ...
        'Tag','Frame2');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'Callback','clear rSigp rSigd rSigt rSigs', ...
        'Position',[14.25 84 68.25 21.75], ...
        'String','Clear signals', ...
        'Tag','Btn_Clear');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','right', ...
        'Position',[9.75 316.5 88.5 11.25], ...
        'String','Bits to phase table p=', ...
        'Style','text', ...
        'Tag','Text_iP');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','right', ...
        'Position',[12.75 348 83.25 13.5], ...
        'String','Accumulator width n=', ...
        'Style','text', ...
        'Tag','Text_iN');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[1 1 1], ...
        'HorizontalAlignment','left', ...
        'Position',[101.25 346.5 45 15], ...
        'String','11', ...
        'Style','edit', ...
        'Tag','Edit_iN');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[1 1 1], ...
        'HorizontalAlignment','left', ...
        'Position',[101.25 314.25 45 15], ...
        'String','5', ...
        'Style','edit', ...
        'Tag','Edit_iP');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gTrunc = iValue;', ...
        'Position',[157.5 312 93 17.25], ...
        'String','Phase truncation', ...
        'Style','checkbox', ...
        'Tag','Check_gTrunc', ...
        'Value',1);

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gQuant = iValue;', ...
        'Position',[157.5 267 96 17.25], ...
        'String','Amplitude quantization', ...
        'Style','checkbox', ...
        'Tag','Check_gQuant');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gDit = iValue;', ...
        'Position',[158.25 216 95.25 18], ...
        'String','Phase dithering', ...
        'Style','checkbox', ...
        'Tag','Check_gDit');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','right', ...
        'Position',[14.25 267.75 81.75 13.5], ...
        'String','Amplitude bits b=', ...
        'Style','text', ...
        'Tag','Text_iB');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[1 1 1], ...
        'HorizontalAlignment','left', ...
        'Position',[101.25 267.75 45 15], ...
        'String','6', ...
        'Style','edit', ...
        'Tag','Edit_iB');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','right', ...
        'Position',[12.75 364.5 84 15], ...
        'String','Tuning number F=', ...
        'Style','text', ...
        'Tag','Text_iF');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[1 1 1], ...
        'HorizontalAlignment','left', ...
        'Position',[101.25 365.25 45 15], ...
        'String','32', ...
        'Style','edit', ...
        'Tag','Edit_iF');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gStem = iValue;', ...
        'Position',[98.25 101.25 50.25 15], ...
        'String','Stem', ...
        'Style','checkbox', ...
        'Tag','Check_gStem');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gAugment = iValue;', ...
        'Position',[98.25 83.25 50.25 15], ...
        'String','Augment', ...
        'Style','checkbox', ...
        'Tag','Check_gAugment', ...
        'Value',1);

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'Callback','ddsgt;', ...
        'Position',[98.25 154.5 209.25 24], ...
        'String','Simulate', ...
        'Tag','Btn_Simulate');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gClear = iValue;', ...
        'Position',[14.25 108.75 67.5 15], ...
        'String','Clear in run', ...
        'Style','checkbox', ...
        'Tag','Check_gClear');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','right', ...
        'Position',[156.75 364.5 95.25 15], ...
        'String','Driving frequency [Hz] fv=', ...
        'Style','text', ...
        'Tag','Text_Fv');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[1 1 1], ...
        'HorizontalAlignment','left', ...
        'Position',[256.5 365.25 45 15], ...
        'String','1', ...
        'Style','edit', ...
        'Tag','Edit_Fv', ...
        'Value',1);

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','right', ...
        'Position',[15 217.5 84 15], ...
        'String','Polynomial degree dp=', ...
        'Style','text', ...
        'Tag','Text_iDitPoly');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[1 1 1], ...
        'HorizontalAlignment','left', ...
        'Position',[102.75 218.25 45 15], ...
        'String','10', ...
        'Style','edit', ...
        'Tag','Edit_iDitPoly');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','right', ...
        'Position',[16.5 198.75 81.75 15], ...
        'String','Dithered bits db=', ...
        'Style','text', ...
        'Tag','Text_iDitBits');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[1 1 1], ...
        'HorizontalAlignment','left', ...
        'Position',[102.75 199.5 45 15], ...
        'String','7', ...
        'Style','edit', ...
        'Tag','Edit_iDitBits');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','right', ...
        'Position',[15 250.5 81 13.5], ...
        'String','Amplitude offset aoff=', ...
        'Style','text', ...
        'Tag','Text_Aoff');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[1 1 1], ...
        'HorizontalAlignment','left', ...
        'Position',[101.25 249.75 45 15], ...
        'String','0.7', ...
        'Style','edit', ...
        'Tag','Edit_Aoff');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','right', ...
        'Position',[9.75 299.25 88.5 11.25], ...
        'String','Phase delta offset poff=', ...
        'Style','text', ...
        'Tag','Text_Poff');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[1 1 1], ...
        'HorizontalAlignment','left', ...
        'Position',[101.25 297 45 15], ...
        'String','0.5', ...
        'Style','edit', ...
        'Tag','Edit_Poff');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'Callback','ddsfplot;', ...
        'Position',[210 83.25 94.5 33.75], ...
        'String','Plot spectrum', ...
        'Tag','Btn_Plot');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'Callback','ddsgset;', ...
        'Position',[14.25 129.75 68.25 22.5], ...
        'String','Set parameters', ...
        'Tag','Btn_SetParameters');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'Callback','ddsgini;', ...
        'Position',[14.25 155.25 68.25 22.5], ...
        'String','Initialize', ...
        'Tag','Btn_Initialize');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','left', ...
        'Position',[99 129 207 22.5], ...
        'String','> Idle (L=64s) ', ...
        'Style','text', ...
        'Tag','Text_Message');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'FontAngle','italic', ...
        'FontName','Helvetica', ...
        'FontSize',14, ...
        'Position',[93 393 129 15], ...
        'String','DDS Simulation', ...
        'Style','text', ...
        'Tag','StaticText1');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gData = iValue;', ...
        'Position',[156 101.25 50.25 15], ...
        'String','Data', ...
        'Style','checkbox', ...
        'Tag','Check_gData', ...
        'Value',1);

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gInPlot = iValue;', ...
        'Position',[156 83.25 50.25 15], ...
        'String','In plot', ...
        'Style','checkbox', ...
        'Tag','Check_gInPlot', ...
        'Value',1);

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'Callback','ddsftime', ...
        'Position',[180 33.75 123.75 27.75], ...
        'String','Time plots', ...
        'Tag','Btn_TimePlots');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[1 1 1], ...
        'HorizontalAlignment','left', ...
        'Position',[75.75 46.5 45 15], ...
        'String','1', ...
        'Style','edit', ...
        'Tag','Edit_iSampleStart');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','left', ...
        'Position',[14.25 46.5 59.25 15], ...
        'String','Starting sample:', ...
        'Style','text', ...
        'Tag','Text_iSampleStart');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'HorizontalAlignment','left', ...
        'Position',[14.25 30 59.25 15], ...
        'String','Ending sample:', ...
        'Style','text', ...
        'Tag','Text_iSampleEnd');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gTPhase = iValue;', ...
        'Position',[125.25 47.25 50.25 15], ...
        'String','Phase', ...
        'Style','checkbox', ...
        'Tag','Check_gTPhase', ...
        'Value',1);

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gTDither = iValue;', ...
        'Position',[125.25 30 50.25 15], ...
        'String','Dithered', ...
        'Style','checkbox', ...
        'Tag','Check_gTDither');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gTTrunc = iValue;', ...
        'Position',[125.25 12.75 50.25 15], ...
        'String','Trunc', ...
        'Style','checkbox', ...
        'Tag','Check_gTTrunc');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gTAmplitude = iValue;', ...
        'Position',[180.75 12.75 53.25 15], ...
        'String','Amplitude', ...
        'Style','checkbox', ...
        'Tag','Check_gTAmplitude');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[0.752941 0.752941 0.752941], ...
        'Callback','iValue = get( gcbo, ''Value'' );gTQuant = iValue;', ...
        'Position',[246 12.75 53.25 15], ...
        'String','Quantized', ...
        'Style','checkbox', ...
        'Tag','Check_gTQuant');

b = uicontrol('Parent',a, ...
        'Units','points', ...
        'BackgroundColor',[1 1 1], ...
        'HorizontalAlignment','left', ...
        'Position',[75.75 30 45 15], ...
        'String','100', ...
        'Style','edit', ...
        'Tag','Edit_iSampleEnd');

% ---- GUI objects created ----
