% ----------------------------------------------------------------
%   DDSGINI.M   [Init] button DDS callback.
%   The module initializes parameters, but only if they are
%   non-existent. This setup avoids cleaning up all the previously
%   set variables. For initializing everything from scratch,
%   type 'clear all' or 'clear' on our MATLAB prompt and then
%   pres [Init] button.
%
%   In any case, the module sets the current variable setting
%   to the boxes in GUI. Press [Init] every time you changed
%   something manually from MATLAB prompt. Simulation ALWAYS
%   reads the GUI boxes and sets the variables according to them
%   (by calling ddsgset.m)!
%   
%   Input:	Clear or set all DDS variables
%   Output:	gShell = 1
%		Variables set
%		Boxes in GUI set according to the current DDS
%		variables values
%   Calls:	ddsini.m
%
%   Author: Martin Pechanec, Febraury 14, 1998
%           pechanec@iname.com
% ----------------------------------------------------------------

% -- Set the variable that we are in the shell
gShell = 1;

% -- Check whether the initialization is necessary.
%    Check only significant values!

if 7 ~= ( exist( 'iF') + ...
         exist( 'iN' ) + ...
         exist( 'iP' ) + ...
         exist( 'iB' ) + ...
         exist( 'Poff' ) + ...
         exist( 'Aoff' ) + ...
         exist( 'Fv' ) ),
  ddsini;
  gShell = 1;		% We are in the shell
end

iHandle = findobj( gcbf, 'Tag', 'Edit_iF' );
set( iHandle, 'String', num2str( iF ) );

iHandle = findobj( gcbf, 'Tag', 'Edit_Fv' );
set( iHandle, 'String', num2str( Fv ) );

iHandle = findobj( gcbf, 'Tag', 'Edit_iP' );
set( iHandle, 'String', num2str( iP ) );

iHandle = findobj( gcbf, 'Tag', 'Edit_iN' );
set( iHandle, 'String', num2str( iN ) );

iHandle = findobj( gcbf, 'Tag', 'Edit_Poff' );
set( iHandle, 'String', num2str( Poff ) );

iHandle = findobj( gcbf, 'Tag', 'Edit_Aoff' );
set( iHandle, 'String', num2str( Aoff ) );

iHandle = findobj( gcbf, 'Tag', 'Edit_iB' );
set( iHandle, 'String', num2str( iB ) );

iHandle = findobj( gcbf, 'Tag', 'Edit_iDitPoly' );
set( iHandle, 'String', num2str( iDitPoly ) );

iHandle = findobj( gcbf, 'Tag', 'Edit_iDitBits' );
set( iHandle, 'String', num2str( iDitBits ) );

iHandle = findobj( gcbf, 'Tag', 'Edit_iSampleStart' );
set( iHandle, 'String', num2str( iSampleStart ) );

iHandle = findobj( gcbf, 'Tag', 'Edit_iSampleEnd' );
set( iHandle, 'String', num2str( iSampleEnd ) );

% -- Set check boxes
iHandle = findobj( gcbf, 'Tag', 'Check_gTrunc' );
set( iHandle, 'Value', gTrunc );

iHandle = findobj( gcbf, 'Tag', 'Check_gQuant' );
set( iHandle, 'Value', gQuant );

iHandle = findobj( gcbf, 'Tag', 'Check_gDit' );
set( iHandle, 'Value', gDit );

iHandle = findobj( gcbf, 'Tag', 'Check_gStem' );
set( iHandle, 'Value', gStem );

iHandle = findobj( gcbf, 'Tag', 'Check_gAugment' );
set( iHandle, 'Value', gAugment );

iHandle = findobj( gcbf, 'Tag', 'Check_gClear' );
set( iHandle, 'Value', gClear );

iHandle = findobj( gcbf, 'Tag', 'Check_gData' );
set( iHandle, 'Value', gData );

iHandle = findobj( gcbf, 'Tag', 'Check_gInPlot' );
set( iHandle, 'Value', gInPlot );

iHandle = findobj( gcbf, 'Tag', 'Check_gTPhase' );
set( iHandle, 'Value', gTPhase );

iHandle = findobj( gcbf, 'Tag', 'Check_gTDither' );
set( iHandle, 'Value', gTDither );

iHandle = findobj( gcbf, 'Tag', 'Check_gTTrunc' );
set( iHandle, 'Value', gTTrunc );

iHandle = findobj( gcbf, 'Tag', 'Check_gTAmplitude' );
set( iHandle, 'Value', gTAmplitude );

iHandle = findobj( gcbf, 'Tag', 'Check_gTQuant' );
set( iHandle, 'Value', gTQuant );

