% ----------------------------------------------------------------
%   DDSINI.M   DDS simulator initialization file.
%   This module initializes all the necessary DDS simulation
%   parameters. If GUI is not used this must be the first
%   file executed from the MATLAB command line. Then
%   the simulation can be done by runnig ddsgt.m.
%
%   Input:      ---
%   Output:     DDS simulation variables created and initialized
%   Calls:      ---
%
%   Author: Martin Pechanec, Febraury 18, 1997
%           pechanec@iname.com
% ----------------------------------------------------------------

% -- Set format to compact
format compact;

% -- Initialize simulation the values
Fv = 1; % Driving frequency [Hz]
iN = 11; % Number of acummulator bits
iP = 5;  % Bits passed to the phase/sin conversion
iF = 2^(iN-iP-1);  % Tuning number for maximum spur level
iQ = iN - iP;  % Truncated bits

iB = 6;     % Quantization bits
Aoff = 0.7; % Amplitude quantizaion level offset .. best result
Poff = 1/2; % Phase offset

gDit = 0;   % No phase dither (Boolean variable 'g')
iDitPoly = 10; % Dither polynomial degree
iDitBits = 7;  % Dither bits

gQuant = 0;     % No amplitude quantization
gTrunc = 1;     % Phase truncation

gClear = 0;     % Set clearing flag for memory saving purposes

gAugment = 1;   % Plotting - augment the spectrum
gStem = 0;      % Stem instead of plot
iIndBase = 1;   % Index base for time plotting. Keep it at one
                % for MATLAB compatibility. It can be changed
                % to 0 to get 0-based time indices (first sample
                % at index 0 rather than 1

gShell = 0;     % Run manually
gData = 1;      % Print data in the plot or figure
gInPlot = 0;    % Print data out of the plot (1 .. in the plot)
gPrintMsg = 0;  % Assume we are at PC, so do not print message
                % in the MATLAB window. Change to 1 if on UNIX
                % or if there are problems with GUI

PsdFloor = -100; % Psd calculation floor in [dB]
FigFloor = -100; % Spectral figure plotting in [dB]. Figure will
                 % use max( PsdFloor, FigFloor )

% -- Time plotting flags and limits
gTPhase = 0;
gTDither = 0;
gTTrunc = 0;
gTAmplitude = 0;
gTQuant = 0;

iSampleStart = 1;
iSampleEnd = 100;

% -- Set the generator polynomials as a row of cells 'rc'
rcGen = cells( 1, 25 );

rcGen{1} = [ 1 1 ];                     % h(x)= 1+x^1
rcGen{2} = [ 1 1 1 ];                   % h(x)= 1+x^1+x^2
rcGen{3} = [ 1 1 0 1 ];                 % h(x)= 1+x^1+x^3
rcGen{4} = [ 1 1 0 0 1 ];               % h(x)= 1+x^1+x^4
rcGen{5} = [ 1 0 1 0 0 1 ];             % h(x)= 1+x^2+x^5
rcGen{6} = [ 1 1 0 0 0 0 1 ];           % h(x)= 1+x^1+x^6
rcGen{7} = [ 1 1 0 0 0 0 0 1 ];         % h(x)= 1+x^1+x^7
rcGen{8} = [ 1 0 1 1 1 0 0 0 1 ];       % h(x)= 1+x^2+x^3+x^4+x^8
rcGen{9} = [ 1 0 0 0 1 0 0 0 0 1 ];     % h(x)= 1+x^4+x^9

rcGen{10} = [ 1 0 0 1 0 0 0 0 0 0 1 ];                  % h(x)= 1+x^3+x^10
rcGen{11} = [ 1 0 1 0 0 0 0 0 0 0 0 1 ];                % h(x)= 1+x^2+x^11
rcGen{12} = [ 1 1 0 0 1 0 1 0 0 0 0 0 1 ];              % h(x)= 1+x^1+x^4+x^6+x^12
rcGen{13} = [ 1 1 0 1 1 0 0 0 0 0 0 0 0 1 ];            % h(x)= 1+x^1+x^3+x^4+x^13
rcGen{14} = [ 1 1 0 1 0 1 0 0 0 0 0 0 0 0 1 ];          % h(x)= 1+x^1+x^3+x^5+x^14
rcGen{15} = [ 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 1 ];        % h(x)= 1+x^1+x^15
rcGen{16} = [ 1 0 1 1 0 1 0 0 0 0 0 0 0 0 0 0 1 ];      % h(x)= 1+x^2+x^3+x^5+x^16
rcGen{17} = [ 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 1 ];    % h(x)= 1+x^3+x^17

rcGen{18} = [ 1 1 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 1 ];          % h(x)= 1+x^1+x^2+x^5+x^18
rcGen{19} = [ 1 1 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 1 ];        % h(x)= 1+x^1+x^2+x^5+x^19
rcGen{20} = [ 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 ];      % h(x)= 1+x^3+x^20
rcGen{21} = [ 1 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 ];    % h(x)= 1+x^2+x^21
rcGen{22} = [ 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 ];  % h(x)= 1+x^1+x^22
rcGen{23} = [ 1 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 ];     % h(x)= 1+x^5+x^23
rcGen{24} = [ 1 1 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 ];   % h(x)= 1+x^1+x^3+x^4+x^24
rcGen{25} = [ 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 ]; % h(x)= 1+x^3+x^25
