function ioHandle = ddsplot( riX, riY, siFormat )
%DDS spectal plot.
%
%   H = DDSPLOT(Y) plots the spectral lines of the psd
%   H = DDSPLOT(X,Y) does the same but according to the frequency
%       vector X
%   H = DDSPLOT(X,Y,S) does the same as above, but using the format string.
%       Only the line colors and types are permitted!
%
%       X .. frequency vector
%       Y .. psd vector
%       S .. format string
%
%       H .. output figure handle

%   Author: Martin Pechanec, October 22, 1997
%           pechanec@iname.com

% -- Check the number of input arguments
switch nargin
  case 1
    iN = length( riX );
    riY = riX;
    rFreq = [0:iN-1];
    siFormat = 'b-';

  case 2
    rFreq = iX;
    siFormat = 'b-';

  case 3
    rFreq = iX;

  otherwise
    error( 'DDSPLOT: Wrong number of input parameters. It can be 1, 2, or 3 only!' );
end

% -- Plot the values
iHandle = plot( rFreq, riY, siFormat );
rAxis = axis;
axis( [ 0 rFreq(iN-1) rAxis(3:4) ] );
grid on;
zoom;

if ( nargout > 0 )
  ioHandle = iHandle;
end
