function coYnum = vectbin( miV, siDirection )
%VECTBIN binary vector or row vectors to an integer number conversion
%   Y = VECTBIN(V) converts the row vectors of V to column of numbers.
%	The bits V(:,1) is 2^0, V(:,2) is 2^1 etc.
%
%   Y = VECTBIN(V,'high') same, but the powers of 2 are
%       reversed. The default is 'low' (2^0=1 starts at lowest
%	row vector index, if 'high', then it starts at highest
%	row vector index).

%   Author: Martin Pechanec, November 12, 1997
%           pechanec@iname.com

% -- Set the conversion direction
[iR,iC] = size( miV );
if ( nargin > 1 )
  if 1 == strcmp( siDirection, 'high' )
    rPow2 = 2 .^ [iC-1:-1:0];
  else
    rPow2 = 2 .^ [0:iC-1];
  end
else
  rPow2 = 2 .^ [0:iC-1];
end

% -- Calculate the output
coYnum = miV * rPow2';

